__author__ = 'Derek Payton <derek.payton@gmail.com>'
__copyright__ = 'Copyright (c) Derek Payton'
__description__ = 'Extended EmailField validation using flanker'
__version__ = '0.2.0'
__license__ = 'MIT License'
